/*F
   |**********************************************************************;
  Project           : Dashboard Aprilia RS 125 ATMega2560pro
                      -Drehzahl per I2C von Arduino Nano
                      -Ausgabe auf LCD 128x64
                      -Startup Sequenz mit bitmap Ausgabe
                      -Menüseiten per Pushbutton
                      -Temperaturmessung per DS18B20
                      -
  Program name      : 

  Author            : JimmyRR

  Date created      : 20210415

  Modified by       : 

  Revision History  :

  Date modifiied    Vers.   Revision Date
  20210419          1.0     

  |**********************************************************************;
*/

//Datenübertragung Arduino I2C//
#include <I2C_Anything.h>
#include <Wire.h>
const byte MY_ADDRESS = 42;
////////////////////////////////

//Display//
#include <U8g2lib.h>
#include <SPI.h>
#include <Arduino.h>
///////////

//Wassertemperatur//
#include <OneWire.h>
#include <DallasTemperature.h>
#define ONE_WIRE_BUS 22  // One Wire Bus für z.B. Temp.fühler an PIN22
//#define TEMPERATURE_PRECISION 9 //Temp.fühler Präzision
///////////////////

//TABS vorziehen um kompiler Fehler zu umgehen//
void startup();
void setPage1();
void setPage2();
void setPage3();
/////////////////////////////////

//Display//
U8G2_ST7920_128X64_F_SW_SPI u8g2(U8G2_R0, /* clock=*/ 52, /* data=*/ 51, /* CS=*/ 53, /* reset=*/ 8);
const byte btnpin = 37;  // Page Button an Pin 37
byte seite = 1;          // Voreinstellung der Seite
byte maxseite = 3;       // max Anzahl
//////////

//Schalter+Taster//
bool button;            // Zustand des Eingangs
bool buttonflag;        // Hilfsflag für den Taster

//Messungen//
int temp1 = 0;  //Temp1 (Kopf) Nullen
OneWire oneWire(ONE_WIRE_BUS);  // Setup a oneWire instance to communicate with any OneWire devices (not just Maxim/Dallas temperature ICs)
DallasTemperature sensors(&oneWire);  // Pass our oneWire reference to Dallas Temperature.

DeviceAddress kopfTemp = { 0x28, 0x53, 0x6E, 0x56, 0xB5, 0x01, 0x3C, 0x5B };
/////////////

/*##########################_SETUP_################################*/
void setup() {

  Serial.begin(115200);         // braucht man nicht (fuer seriellen Monitor, Kontrollausgabe)

//Display//
  u8g2.begin();

  
//Schalter+Taster//
  pinMode (btnpin, INPUT_PULLUP);   //Page Button als Eingang

//Messungen//
  sensors.begin();
  sensors.setResolution(kopfTemp, 9); //Temp.fühler Auflösung 9,10,11,12 bit
  sensors.setWaitForConversion(false); //request temp nicht blockierend!  

//Datenübertragung Arduino I2C//
  Wire.begin (MY_ADDRESS);
  Wire.onReceive (receiveEvent);

//Startup//
  startup();  //Start-Sequenz aufrufen

}

//Variablen Datenübertragung//
volatile boolean haveData = false;
volatile float frequency;   // Variable der Drehzahl aus Arduino Nano
//volatile long foo;

/*##########################_LOOP_#################################*/


void loop() {

 if (haveData)
    {
    Serial.print ("Received rpm = ");   // Nur für
    Serial.println (frequency);         // Testzwecke!
    //Serial.print ("Received foo = ");
    //Serial.println (foo);
    haveData = false;
    }  // end if haveData


/*------------------------Display_Menü------------------------------*/


  button = !digitalRead(btnpin); // Taster einlesen und invertieren

  // Seitenumschaltung
  if (button == true && buttonflag == false) { // Pos. Flanke erkennen
    delay(10);        // Taster entprellen
    buttonflag = true;//  Status setzen
    seite++;
    if (seite > maxseite) seite = 1; // auf Anfang
  }
  // Wenn der Taster nicht gedrückt ist dann das Hiflsflag zurück
  if (button == false) buttonflag = false;

  // Auswertung der aktuellen Seite
  if (seite == 1) {
    //Serial.println("Seite 1 angewählt");
    setPage1();

  }
  else if (seite == 2) {
    //Serial.println("Seite 2 angewählt");
    setPage2();
  }

  else if (seite == 3) {
    //Serial.println("Seite 3 angewählt");
    setPage3();
  }


  
  }


/*#####################_Daten_Empfang_Interrupt_##########################*/

//called by interrupt service routine when incoming data arrives
void receiveEvent (int howMany)
 {
 if (howMany >= (sizeof frequency)) //+ (sizeof frequency))
   {
   I2C_readAnything (frequency);
   //I2C_readAnything (foo);
   haveData = true;
   }  // end if have enough data
 }  // end of receiveEvent

//***************************END of PROGRAM******************************************;
